==> adephylo_1.0-2.tar.gz: adephylo/man/treePart.Rd <==
\name{treePart}
\alias{treePart}
\title{Define partitions of tips according from a tree}
\description{
  The function \code{treePart} defines partitions of tips reflecting the
  topology of a tree. There are two possible outputs (handled by the
  argument \code{result}):\cr
  - \code{basis} mode: each node but the root is translated into a dummy
  vector having one value for each tip: this value is '1' if the tip
  descends from this node, and '0' otherwise.\cr
  - \code{orthobasis}: in this mode, an orthonormal basis is derived
  from the basis previously mentionned. This orthobasis was proposed in
  the orthogram (Ollier \emph{et al.} 2006).
}
\usage{
treePart(x, result=c("dummy", "orthobasis"))
}
\arguments{
  \item{x}{a tree of  class \code{\link[ape:read.tree]{phylo}},
    \linkS4class{phylo4} or \linkS4class{phylo4d}.}
  \item{result}{a character string specifying the type of result: either
  a basis of dummy vectors (\code{dummy}), or an orthobasis derived from these dummy vectors (\code{orthobasis}).}
}
\value{
  A matrix of numeric vectors (in columns) having one value for each
  tip (rows).
}
\author{ Thibaut Jombart \email{tjombart@imperial.ac.uk} }
\references{
Ollier, S., Chessel, D. and Couteron, P. (2005) Orthonormal Transform to Decompose the Variance of a Life-History Trait across a Phylogenetic Tree. \emph{Biometrics}, \bold{62}, 471--477.
}

\seealso{
  - \code{\link{listDD}} which is called by \code{treePart}.\cr
  - \code{\link{orthogram}}, which uses by default the orthobasis
  produced by \code{treePart}.\cr
}
\details{
  Orthobasis produced by this function are identical to those stored in
  the \$Bscores component of deprecated \link[ade4]{phylog} objects,
  from the ade4 package.
}
\examples{
if(require(ape) & require(phylobase)){
## make a tree
x <- as(rtree(10),"phylo4")
partition <- treePart(x)
partition

## plot the dummy vectors with the tree
temp <- phylo4d(x, partition)
table.phylo4d(temp, cent=FALSE, scale=FALSE)
}

if(require(ade4)){
## former orthobasis in ade4
data(ungulates)
ung.Bscores <- newick2phylog(ungulates$tre)$Bscores

## version using treePart
ung <- read.tree(text=ungulates$tre)
ung.orthobas <- treePart(ung, res="orthobasis")

## comparison of the first 3 vectors
cbind(ung.Bscores[,1], ung.orthobas[,1],ung.Bscores[,2], ung.orthobas[,2], ung.Bscores[,3], ung.orthobas[,3])
}
}
\keyword{manip}

==> adephylo_1.1-4.tar.gz: adephylo/man/treePart.Rd <==
\name{treePart}
\alias{treePart}
\title{Define partitions of tips according from a tree}
\description{
  The function \code{treePart} defines partitions of tips reflecting the
  topology of a tree. There are two possible outputs (handled by the
  argument \code{result}):\cr
  - \code{basis} mode: each node but the root is translated into a dummy
  vector having one value for each tip: this value is '1' if the tip
  descends from this node, and '0' otherwise.\cr
  - \code{orthobasis}: in this mode, an orthonormal basis is derived
  from the basis previously mentionned. This orthobasis was proposed in
  the orthogram (Ollier \emph{et al.} 2006).
}
\usage{
treePart(x, result=c("dummy", "orthobasis"))
}
\arguments{
  \item{x}{a tree of  class \code{\link[ape:read.tree]{phylo}},
    \linkS4class{phylo4} or \linkS4class{phylo4d}.}
  \item{result}{a character string specifying the type of result: either
  a basis of dummy vectors (\code{dummy}), or an orthobasis derived from these dummy vectors (\code{orthobasis}).}
}
\value{
  A matrix of numeric vectors (in columns) having one value for each
  tip (rows).
}
\author{ Thibaut Jombart \email{tjombart@imperial.ac.uk} }
\references{
Ollier, S., Chessel, D. and Couteron, P. (2005) Orthonormal Transform to
Decompose the Variance of a Life-History Trait across a Phylogenetic
Tree. \emph{Biometrics}, \bold{62}, 471--477.
}

\seealso{
  - \code{\link{listDD}} which is called by \code{treePart}.\cr
  - \code{\link{orthogram}}, which uses by default the orthobasis
  produced by \code{treePart}.\cr
}
\details{
  Orthobasis produced by this function are identical to those stored in
  the \$Bscores component of deprecated \link[ade4]{phylog} objects,
  from the ade4 package.
}
\examples{
if(require(ape) & require(phylobase)){
## make a tree
x <- as(rtree(10),"phylo4")
partition <- treePart(x)
partition

## plot the dummy vectors with the tree
temp <- phylo4d(x, partition)
table.phylo4d(temp, cent=FALSE, scale=FALSE)
}

if(require(ade4)){
## former orthobasis in ade4
data(ungulates)
ung.Bscores <- newick2phylog(ungulates$tre)$Bscores

## version using treePart
ung <- read.tree(text=ungulates$tre)
ung.orthobas <- treePart(ung, res="orthobasis")

## comparison of the first 3 vectors
cbind(ung.Bscores[,1], ung.orthobas[,1],ung.Bscores[,2],
   ung.orthobas[,2], ung.Bscores[,3], ung.orthobas[,3])
}
}
\keyword{manip}
